@@ -1,5 +1,18 @@
+/// `Funhouse` wraps any existing type which implements [PartialEq].
+/// However Funhouse implements both `eq` and `ne` identically
+/// resulting in a contradiction.
+///
+/// # Examples
+///
+/// ```
+/// # use misfortunate::Funhouse;
+///
+/// let x = Funhouse('x');
+/// assert!(x == x);
+/// assert!(x != x);
+/// ```
 #[derive(Clone, Debug)]
-pub struct Funhouse<T: PartialEq>(T);
+pub struct Funhouse<T: PartialEq>(pub T);
 
 impl<T: PartialEq> PartialEq for Funhouse<T> {
     fn eq(&self, other: &Self) -> bool {
